@@ -20,6 +20,25 @@ extern GtkBox *syncBox;
 */
 extern gint timer;
 
+/* Normal UI format is to press the "Done" button when finished with 
+   Rendezvous.  Certain users (see Debian bug #213368) seem, however,
+   not to understand that "Done" means, ahem, "done".  To accommodate
+   such users I will allow the "Done" label to be set by the user:
+   in ~/.gworldclock, e.g.:
+   <gworldclock>
+       <rendezvous>
+           <doneLabel>Return</doneLabel>
+       </rendezvous>
+   </gworldclock>
+*/
+
+/* should be left as NULL unless explicitly set by user in config file */
+GString *rendezvousDoneLabel = NULL;
+
+/* keeps track of whether or not Rendezvous is currently running */
+static gboolean rendezvousIsActive = FALSE;
+static gulong leftClickHandlerForRendezvous=0;
+
 /* returns name of month (as defined by locale, converted to UTF-8)
    corresponding to given index (between 1 and 12) */
 gchar* getNameOfMonth( gint index )
@@ -162,13 +181,26 @@ void setDefaultSyncValues(gchar *description, gchar *timezone)
 
 }
 
+/* Allows menu selection to turn Rendezvous on and off. */
+void ToggleRendezvous(GtkToggleAction *action, gpointer clocklist)
+{
+    if ( gtk_toggle_action_get_active( action ) )
+    {
+	Rendezvous( NULL, clocklist );
+    }
+    else
+    {
+	unsynchronise( NULL, clocklist );
+    }		
+}
 
 /* "Synchronise" is labelled "Rendezvous" in the user interface, to help
    users understand the meaning of the function. 
    Correspondingly this function is likewise relabelled */
-void Rendezvous(gpointer clocklist)
+void Rendezvous(GtkWidget *w, gpointer clocklist)
 {
    extern gint changed;
+   
    GString *title, *msg;
    gchar *button[]={"OK"};
    GdkWindow *window;
@@ -177,19 +209,21 @@ void Rendezvous(gpointer clocklist)
    gchar *description, *timezone;
    GtkTreeModel *clocklistModel;
    GtkTreeIter iter;
+   GtkTreeSelection *select;
+   GtkToggleAction *toggleAction;
    
    if ( gtk_tree_selection_get_selected( 
 	   gtk_tree_view_get_selection( clocklist ),
 	   &clocklistModel,
 	   &iter ) )
    {
-      gtk_tree_model_get( clocklistModel, &iter,
-			  TZ_NAME, &timezone,
-			  TZ_DESCRIPTION, &description,
-			  -1);
+       gtk_tree_model_get( clocklistModel, &iter,
+			   TZ_NAME, &timezone,
+			   TZ_DESCRIPTION, &description,
+			   -1);
       
-      /* set sync values to current time */
-      setDefaultSyncValues(description, timezone);
+       /* set sync values to current time */
+       setDefaultSyncValues(description, timezone);
       
       if ( timer != -1 ) {
 	 
@@ -201,10 +235,41 @@ void Rendezvous(gpointer clocklist)
 	 gdk_window_get_size(window, &width, &height);
 	 gdk_window_resize( window, width, height + SYNCBOX_HEIGHT );
       }
+
+      /* enable single clicking on a zone in the list to rendezvous
+	 against that zone */
+      if ( ! rendezvousIsActive )
+      {
+	  if ( leftClickHandlerForRendezvous )
+	  {
+	      g_signal_handler_unblock( 
+		  G_OBJECT(gtk_tree_view_get_selection( clocklist )), 
+		  leftClickHandlerForRendezvous );
+	  }
+	  else
+	  {
+	      leftClickHandlerForRendezvous =
+		  g_signal_connect(G_OBJECT(gtk_tree_view_get_selection( clocklist )),
+				   "changed",
+				   G_CALLBACK(Rendezvous),
+				   (gpointer)clocklist );
+	  }
+      }
+
       
       /* and change display to correspond to given time */
       gtk_widget_show( (GtkWidget *) syncBox );
-      
+
+      rendezvousIsActive = TRUE;
+
+      /* Check the Rendezvous main menu item is toggled on, if we got
+	 here via the popup menu */
+      toggleAction = GTK_TOGGLE_ACTION( gtk_action_group_get_action(
+	  GTK_ACTION_GROUP( g_object_get_data(G_OBJECT(clocklist), ACTIONS) ),
+	  "ToggleRendezvous" ) );
+      gtk_toggle_action_set_active( toggleAction, TRUE );
+
+
    }
    else 
    {
@@ -216,6 +281,7 @@ void Rendezvous(gpointer clocklist)
    }
 }
 
+
 /* reads the values set in the syncBox fields and turns them into
    a time_t time.
    Note: this time_t crashes (mktime returns -1) at 6:45am, 14 Dec 1901
@@ -319,11 +385,18 @@ void synchroniseTimes( GtkWidget *field, gpointer clocklist)
 
 
 /* after done synchronising zones, return back to current time */
-void unsynchronise( GtkWidget *button, gpointer clocklist)
+void unsynchronise( GtkWidget *w, gpointer clocklist)
 {
   GdkWindow *window;
   gint width, height;
 
+  if ( leftClickHandlerForRendezvous )
+  {
+      g_signal_handler_block( 
+	  G_OBJECT(gtk_tree_view_get_selection( clocklist )), 
+	  leftClickHandlerForRendezvous );
+  }
+
   SetTime( clocklist );
   gtk_widget_hide( (GtkWidget *) syncBox );
   
@@ -333,6 +406,8 @@ void unsynchronise( GtkWidget *button, gpointer clocklist)
   gdk_window_resize( window, width, height - SYNCBOX_HEIGHT );
 
   timer = start_timer( clocklist );
+
+  rendezvousIsActive = FALSE;
 }
 
 GList *initialiseMonthList(GList *listMonths)
@@ -356,6 +431,8 @@ GtkBox *constructSyncBox(gpointer clocklist)
 {
    GtkWidget *box, *line, *set;
    GtkWidget *button;
+
+   GString *doneLabel;
    
    GtkWidget *label;
    GtkWidget *hour;
@@ -495,14 +572,20 @@ GtkBox *constructSyncBox(gpointer clocklist)
    
    line = gtk_hbox_new (TRUE, 1);
    /* button to set to new time (for those who dislike the return button */
-   button = gtk_button_new_with_label(_("Update"));
+   button = gtk_button_new_with_label(_("Update View"));
    gtk_box_pack_start(GTK_BOX(line), button, TRUE, FALSE, 0);  
    gtk_signal_connect (GTK_OBJECT (button), "clicked",
 		       GTK_SIGNAL_FUNC (synchroniseTimes),  (gpointer)clocklist);
    gtk_widget_show (button);
    
    /* button to close synchronisation, return to current time */
-   button = gtk_button_new_with_label(_("Done"));
+   if ( rendezvousDoneLabel != NULL )
+       doneLabel = g_string_new( rendezvousDoneLabel->str );
+   else /* normal behaviour */
+       doneLabel = g_string_new( _("Done") );
+   button = gtk_button_new_with_label( doneLabel->str );
+   g_string_free( doneLabel, TRUE );
+
    gtk_box_pack_start(GTK_BOX(line), button, TRUE, FALSE, 0);  
    gtk_signal_connect (GTK_OBJECT (button), "clicked",
 		       GTK_SIGNAL_FUNC (unsynchronise),  (gpointer)clocklist);
