@@ -12,14 +12,14 @@
 #define _(A) gettext(A)
 
 
-void DeleteZone( gpointer clocklist )
+void DeleteZone( GtkWidget *w, gpointer clocklist )
 {
    extern gint changed;
    GString *title, *msg;
    gchar *button[]={"OK"};
    GtkTreeModel *clocklistModel;
    GtkTreeIter iter;
-   
+
    if ( gtk_tree_selection_get_selected( 
 	   gtk_tree_view_get_selection( clocklist ),
 	   &clocklistModel,
@@ -42,7 +42,7 @@ void DeleteZone( gpointer clocklist )
 
 
 /*  Save list of time zones to configfile */
-gint SaveZones(gpointer clocklist)
+gint SaveZones(GtkWidget *w, gpointer clocklist)
 {
   FILE *cf;
   extern GString *configfile;
@@ -572,7 +572,7 @@ void AddZoneToList(GtkWidget *w, gpointer NewZone)
   g_string_free(TZ,TRUE);
 }
 
-void AddZone( gpointer clocklist )
+void AddZone( GtkWidget *w, gpointer clocklist )
 {
   GtkWidget *window; 
   GtkWidget *vbox, *hbox;
@@ -702,7 +702,7 @@ void WriteZoneDescription(GtkDialog *dialog, gint responseId, gpointer Zone)
   }
 }
   
-void ChangeZoneDescription(gpointer clocklist)
+void ChangeZoneDescription(GtkWidget *w, gpointer clocklist)
 {
   gchar *description;
   GtkWidget *window, *vbox, *hbox;
